@@ -19,7 +19,7 @@ from azure.cli.command_modules.acs._consts import (
 )
 from azure.cli.command_modules.acs._resourcegroup import get_rg_location
 from azure.cli.command_modules.acs._roleassignments import add_role_assignment
-from azure.cli.core.azclierror import AzCLIError, CLIError, InvalidArgumentValueError
+from azure.cli.core.azclierror import AzCLIError, CLIError, InvalidArgumentValueError, ArgumentUsageError
 from azure.cli.core.profiles import ResourceType
 from azure.cli.core.util import send_raw_request
 from azure.core.exceptions import HttpResponseError
@@ -185,6 +185,21 @@ AzureUSSecRegionToOmsRegionMap = {
     "ussecwest": "ussecwest",
 }
 
+ContainerInsightsStreams = [
+    "Microsoft-ContainerLog",
+    "Microsoft-ContainerLogV2-HighScale",
+    "Microsoft-KubeEvents",
+    "Microsoft-KubePodInventory",
+    "Microsoft-KubeNodeInventory",
+    "Microsoft-KubePVInventory",
+    "Microsoft-KubeServices",
+    "Microsoft-KubeMonAgentEvents",
+    "Microsoft-InsightsMetrics",
+    "Microsoft-ContainerInventory",
+    "Microsoft-ContainerNodeInventory",
+    "Microsoft-Perf",
+]
+
 
 # pylint: disable=too-many-locals
 def ensure_default_log_analytics_workspace_for_monitoring(
@@ -330,7 +345,10 @@ def ensure_container_insights_for_monitoring(
     create_dcr=False,
     create_dcra=False,
     enable_syslog=False,
-    data_collection_settings=None
+    data_collection_settings=None,
+    is_private_cluster=False,
+    ampls_resource_id=None,
+    enable_high_log_scale_mode=False,
 ):
     """
     Either adds the ContainerInsights solution to a LA Workspace OR sets up a DCR (Data Collection Rule) and DCRA
@@ -347,6 +365,9 @@ def ensure_container_insights_for_monitoring(
     if not addon.enabled:
         return None
 
+    if (not is_private_cluster or not aad_route) and ampls_resource_id is not None:
+        raise ArgumentUsageError("--ampls-resource-id can only be used with private cluster in MSI mode.")
+
     # workaround for this addon key which has been seen lowercased in the wild
     for key in list(addon.config):
         if (
@@ -364,12 +385,19 @@ def ensure_container_insights_for_monitoring(
         workspace_resource_id
     )
 
-    # extract subscription ID and resource group from workspace_resource_id URL
+    # extract subscription ID and workspace name from workspace_resource_id
     try:
         subscription_id = workspace_resource_id.split("/")[2]
     except IndexError:
         raise AzCLIError(
-            "Could not locate resource group in workspace-resource-id URL."
+            "Could not locate resource group in workspace-resource-id."
+        )
+
+    try:
+        workspace_name = workspace_resource_id.split("/")[8]
+    except IndexError:
+        raise AzCLIError(
+            "Could not locate workspace name in --workspace-resource-id."
         )
 
     location = ""
@@ -386,7 +414,7 @@ def ensure_container_insights_for_monitoring(
         except HttpResponseError as ex:
             raise ex
 
-    if aad_route:
+    if aad_route:  # pylint: disable=too-many-nested-blocks
         cluster_resource_id = (
             f"/subscriptions/{cluster_subscription}/resourceGroups/{cluster_resource_group_name}/"
             f"providers/Microsoft.ContainerService/managedClusters/{cluster_name}"
@@ -398,6 +426,44 @@ def ensure_container_insights_for_monitoring(
             f"/subscriptions/{cluster_subscription}/resourceGroups/{cluster_resource_group_name}/"
             f"providers/Microsoft.Insights/dataCollectionRules/{dataCollectionRuleName}"
         )
+
+        dataCollectionEndpointName = f"MSCI-{location}-{cluster_name}"
+        # Max length of the DCE name is 44 chars
+        dataCollectionEndpointName = dataCollectionEndpointName[0:43]
+        dce_resource_id = None
+
+        if enable_high_log_scale_mode or (ampls_resource_id is not None):
+            dce_resource_id = (
+                f"/subscriptions/{cluster_subscription}/resourceGroups/{cluster_resource_group_name}/"
+                f"providers/Microsoft.Insights/dataCollectionEndpoints/{dataCollectionEndpointName}"
+            )
+            dce_url = cmd.cli_ctx.cloud.endpoints.resource_manager + \
+                f"{dce_resource_id}?api-version=2022-06-01"
+            # create the DCE
+            dce_creation_body_common = {
+                "location": location,
+                "kind": "Linux",
+                "properties": {
+                    "networkAcls": {
+                        "publicNetworkAccess": "Enabled"
+                    }
+                }
+            }
+            if ampls_resource_id is not None:
+                dce_creation_body_common["properties"]["networkAcls"]["publicNetworkAccess"] = "Disabled"
+            dce_creation_body_ = json.dumps(dce_creation_body_common)
+            for _ in range(3):
+                try:
+                    send_raw_request(
+                        cmd.cli_ctx, "PUT", dce_url, body=dce_creation_body_
+                    )
+                    error = None
+                    break
+                except AzCLIError as e:
+                    error = e
+            else:
+                raise error
+
         if create_dcr:
             # first get the association between region display names and region IDs (because for some reason
             # the "which RPs are available in which regions" check returns region display names)
@@ -431,6 +497,8 @@ def ensure_container_insights_for_monitoring(
             # get data collection settings
             extensionSettings = {}
             cistreams = ["Microsoft-ContainerInsights-Group-Default"]
+            if enable_high_log_scale_mode:
+                cistreams = ContainerInsightsStreams
             if data_collection_settings is not None:
                 dataCollectionSettings = _get_data_collection_settings(data_collection_settings)
                 validate_data_collection_settings(dataCollectionSettings)
@@ -444,6 +512,10 @@ def ensure_container_insights_for_monitoring(
                 }
                 extensionSettings["dataCollectionSettings"] = dataCollectionSettings
 
+            if enable_high_log_scale_mode:
+                for i in range(len(cistreams)):
+                    if cistreams[i] == "Microsoft-ContainerLogV2":
+                        cistreams[i] = "Microsoft-ContainerLogV2-HighScale"
             # create the DCR
             dcr_creation_body_without_syslog = json.dumps(
                 {
@@ -475,6 +547,7 @@ def ensure_container_insights_for_monitoring(
                                 }
                             ]
                         },
+                        "dataCollectionEndpointId": dce_resource_id
                     },
                 }
             )
@@ -555,6 +628,7 @@ def ensure_container_insights_for_monitoring(
                                 }
                             ]
                         },
+                        "dataCollectionEndpointId": dce_resource_id
                     },
                 }
             )
@@ -603,6 +677,85 @@ def ensure_container_insights_for_monitoring(
                     error = e
             else:
                 raise error
+            # create dce association
+            if enable_high_log_scale_mode or (ampls_resource_id is not None):
+                association_body = json.dumps(
+                    {
+                        "location": cluster_region,
+                        "properties": {
+                            "dataCollectionEndpointId": dce_resource_id,
+                            "description": "routes monitoring data to a Log Analytics workspace",
+                        },
+                    }
+                )
+                association_url = cmd.cli_ctx.cloud.endpoints.resource_manager + \
+                    f"{cluster_resource_id}/providers/Microsoft.Insights/dataCollectionRuleAssociations/configurationAccessEndpoint?api-version=2022-06-01"
+                for _ in range(3):
+                    try:
+                        send_raw_request(
+                            cmd.cli_ctx,
+                            "PUT" if not remove_monitoring else "DELETE",
+                            association_url,
+                            body=association_body,
+                        )
+                        error = None
+                        break
+                    except AzCLIError as e:
+                        error = e
+                else:
+                    raise error
+                if ampls_resource_id is not None:
+                    # link DCE to AMPLS
+                    link_dce_ampls_body = json.dumps(
+                        {
+                            "properties": {
+                                "linkedResourceId": dce_resource_id,
+                            },
+                        }
+                    )
+                    link_dce_ampls_url = cmd.cli_ctx.cloud.endpoints.resource_manager + \
+                        f"{ampls_resource_id}/scopedresources/{dataCollectionEndpointName}-connection?api-version=2021-07-01-preview"
+
+                    for _ in range(3):
+                        try:
+                            send_raw_request(
+                                cmd.cli_ctx,
+                                "PUT",
+                                link_dce_ampls_url,
+                                body=link_dce_ampls_body,
+                            )
+                            error = None
+                            break
+                        except AzCLIError as e:
+                            error = e
+                    else:
+                        raise error
+
+                    # link workspace to AMPLS
+                    link_ws_ampls_body = json.dumps(
+                        {
+                            "properties": {
+                                "linkedResourceId": workspace_resource_id,
+                            },
+                        }
+                    )
+                    link_ws_ampls_url = cmd.cli_ctx.cloud.endpoints.resource_manager + \
+                        f"{ampls_resource_id}/scopedresources/{workspace_name}-connection?api-version=2021-07-01-preview"
+
+                    for _ in range(3):
+                        try:
+                            send_raw_request(
+                                cmd.cli_ctx,
+                                "PUT",
+                                link_ws_ampls_url,
+                                body=link_ws_ampls_body,
+                            )
+                            error = None
+                            break
+                        except AzCLIError as e:
+                            error = e
+                    else:
+                        raise error
 
 
 def validate_data_collection_settings(dataCollectionSettings):
