@@ -12,6 +12,33 @@ type: group
 short-summary: Manage Azure Database for MySQL Flexible Servers.
 """
 
+helps['mysql flexible-server advanced-threat-protection-setting'] = """
+type: group
+short-summary: Manage the server's advanced threat protection setting.
+"""
+
+helps['mysql flexible-server advanced-threat-protection-setting show'] = """
+type: command
+short-summary: Get the server's advanced threat protection setting.
+examples:
+  - name: Get the advanced threat protection setting.
+    text: az mysql flexible-server advanced-threat-protection-setting show -g mygroup -n myserver
+"""
+
+helps['mysql flexible-server advanced-threat-protection-setting update'] = """
+type: command
+short-summary: Update the server's advanced threat protection setting.
+parameters:
+  - name: --state
+    type: string
+    short-summary: 'State of the advanced threat protection setting'
+examples:
+  - name: Enable the advanced threat protection setting.
+    text: az mysql flexible-server advanced-threat-protection-setting update -g mygroup -n myserver --state Enabled
+  - name: Disable the advanced threat protection setting.
+    text: az mysql flexible-server advanced-threat-protection-setting update -g mygroup -n myserver --state Disabled
+"""
+
 helps['mysql flexible-server create'] = """
 type: command
 short-summary: Create a MySQL flexible server.
@@ -212,7 +239,7 @@ long-summary: >
 
 examples:
   - name: >
-      Trigger a Import from azure mysql single server.
+      Trigger an Import from azure mysql single server.
     text: >
         az mysql flexible-server import create --data-source-type mysql_single \\
           --data-source test-single-server --resource-group test-rg \\
@@ -220,6 +247,15 @@ examples:
           --sku-name Standard_B1ms --tier Burstable --public-access 0.0.0.0 \\
           --storage-size 32 --tags "key=value" --version 5.7 --high-availability ZoneRedundant \\
           --zone 1 --standby-zone 3 --storage-auto-grow Enabled --iops 500
+  - name: >
+      Trigger an Online Import from azure mysql single server.
+    text: >
+        az mysql flexible-server import create --data-source-type mysql_single \\
+          --data-source test-single-server --mode "Online" --resource-group test-rg \\
+          --location northeurope --name testserver \\
+          --sku-name Standard_B1ms --tier Burstable --public-access 0.0.0.0 \\
+          --storage-size 32 --tags "key=value" --version 5.7 --high-availability ZoneRedundant \\
+          --zone 1 --standby-zone 3 --storage-auto-grow Enabled --iops 500
   - name: >
       Trigger a Import from source backup stored in azure blob container.
     text: >
