@@ -7,6 +7,7 @@ from knack.log import get_logger
 from azure.cli.core.azclierror import ArgumentUsageError
 from azure.cli.core.aaz import register_command, AAZResourceIdArgFormat, has_value, AAZListArg, AAZResourceIdArg, \
     AAZStrArg, AAZArgEnum
+from msrestazure.tools import is_valid_resource_id, parse_resource_id
 from ..aaz.latest.network.lb import Delete as _LBDelete, Update as _LBUpdate, List as _LBList, Show as _LBShow
 from ..aaz.latest.network.lb.frontend_ip import Create as _LBFrontendIPCreate, Update as _LBFrontendIPUpdate, \
     Show as _LBFrontendIPShow, Delete as _LBFrontendIPDelete, List as _LBFrontendIPList
@@ -275,6 +276,20 @@ class LBRuleCreate(_LBRuleCreate):
             element_transformer=lambda _, id: {"id": id}
         )
 
+    def post_instance_create(self, instance):
+        args = self.ctx.args
+        if has_value(args.frontend_ip_name):
+            curr_id = args.frontend_ip_name.to_serialized_data()
+            curr_name = parse_resource_id(curr_id)["resource_name"] if is_valid_resource_id(curr_id) else curr_id
+
+            parent = self.ctx.vars.instance
+            frontend_ip_configurations = parent.properties.frontend_ip_configurations
+            for fip in frontend_ip_configurations:
+                if fip.name == curr_name:
+                    if has_value(fip.properties.gateway_load_balancer):
+                        rid = fip.properties.gateway_load_balancer.id.to_serialized_data()
+                        self.ctx.update_aux_subscriptions(parse_resource_id(rid)["subscription"])
+
 
 class LBRuleUpdate(_LBRuleUpdate):
 
@@ -324,6 +339,19 @@ class LBRuleUpdate(_LBRuleUpdate):
         # always remove backend_address_pool in update request, service will fill this property based on backend_address_pools property.
         instance.properties.backend_address_pool = None
 
+        args = self.ctx.args
+        if has_value(args.frontend_ip_name):
+            curr_id = args.frontend_ip_name.to_serialized_data()
+            curr_name = parse_resource_id(curr_id)["resource_name"] if is_valid_resource_id(curr_id) else curr_id
+
+            parent = self.ctx.vars.instance
+            frontend_ip_configurations = parent.properties.frontend_ip_configurations
+            for fip in frontend_ip_configurations:
+                if fip.name == curr_name:
+                    if has_value(fip.properties.gateway_load_balancer):
+                        rid = fip.properties.gateway_load_balancer.id.to_serialized_data()
+                        self.ctx.update_aux_subscriptions(parse_resource_id(rid)["subscription"])
+
 
 class LBOutboundRuleCreate(_LBOutboundRuleCreate):
 
@@ -465,7 +493,6 @@ class LBAddressPoolCreate(_LBAddressPoolBasicCreate):
         self.post_operations()
 
     def pre_operations(self):
-        from azure.mgmt.core.tools import is_valid_resource_id
         from azure.cli.core.aaz import AAZUndefined
 
         args = self.ctx.args
@@ -541,7 +568,6 @@ class LBAddressPoolUpdate(_LBAddressPoolUpdate):
         return args_schema
 
     def pre_operations(self):
-        from azure.mgmt.core.tools import is_valid_resource_id
         from azure.cli.core.aaz import AAZUndefined
 
         args = self.ctx.args
@@ -599,8 +625,6 @@ class LBAddressPoolAddressAdd(_LBAddressPoolAddressAdd):
         return args_schema
 
     def pre_operations(self):
-        from azure.mgmt.core.tools import is_valid_resource_id
-
         args = self.ctx.args
         virtual_network = args.virtual_network.to_serialized_data()
         subnet = args.subnet.to_serialized_data()
@@ -637,8 +661,6 @@ class LBAddressPoolAddressUpdate(_LBAddressPoolAddressUpdate):
         return args_schema
 
     def pre_operations(self):
-        from azure.mgmt.core.tools import is_valid_resource_id
-
         args = self.ctx.args
         virtual_network = args.virtual_network.to_serialized_data()
         subnet = args.subnet.to_serialized_data()
