@@ -6,8 +6,7 @@ import string
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from azure.mgmt.security.models import (SecurityContact,
-                                        AutoProvisioningSetting,
+from azure.mgmt.security.models import (AutoProvisioningSetting,
                                         SecurityAssessment,
                                         SecurityAssessmentMetadata,
                                         AzureResourceDetails,
@@ -17,8 +16,6 @@ from azure.mgmt.security.models import (SecurityContact,
                                         Pricing,
                                         WorkspaceSetting,
                                         AdvancedThreatProtectionSetting,
-                                        AlertSyncSettings,
-                                        DataExportSettings,
                                         AlertsSuppressionRule,
                                         SuppressionAlertsScope,
                                         ScopeElement,
@@ -29,8 +26,7 @@ from azure.mgmt.security.models import (SecurityContact,
                                         AutomationActionLogicApp,
                                         AutomationActionEventHub,
                                         AutomationRuleSet,
-                                        AutomationTriggeringRule,
-                                        SettingName)
+                                        AutomationTriggeringRule)
 from azure.mgmt.security.v2020_07_01_preview.models import (RuleResultsInput, RulesResultsInput)
 from azure.mgmt.security.v2023_01_01.models import (Extension)
 from azure.cli.core.commands.client_factory import get_subscription_id
@@ -225,71 +221,6 @@ def delete_security_alerts_suppression_rule_scope(client, rule_name, field):
     return client.update(alerts_suppression_rule_name=rule_name, alerts_suppression_rule=parent_object)
 
 
-# --------------------------------------------------------------------------------------------
-# Security Settings
-# --------------------------------------------------------------------------------------------
-
-
-def list_security_settings(client):
-
-    return client.list()
-
-
-def get_security_setting(client, setting_name):
-
-    return client.get(setting_name)
-
-
-def update_security_setting(client, setting_name, enabled):
-
-    if setting_name == SettingName.SENTINEL:
-        setting = AlertSyncSettings()
-    else:
-        setting = DataExportSettings()
-
-    setting.enabled = enabled
-    return client.update(setting_name, setting)
-
-
-# --------------------------------------------------------------------------------------------
-# Security Contacts
-# --------------------------------------------------------------------------------------------
-
-
-def list_security_contacts(client):
-
-    return client.list()
-
-
-def get_security_contact(client, resource_name):
-
-    return client.get(resource_name)
-
-
-def create_security_contact(client, resource_name, email, phone=None, alert_notifications=None, alerts_admins=None):
-
-    if alert_notifications is None:
-        alert_notifications = ''
-
-    if alerts_admins is None:
-        alerts_admins = ''
-
-    if phone is None:
-        phone = ''
-
-    new_contact = SecurityContact(email=email,
-                                  phone=phone,
-                                  alert_notifications=alert_notifications,
-                                  alerts_to_admins=alerts_admins)
-
-    return client.create(resource_name, new_contact)
-
-
-def delete_security_contact(client, resource_name):
-
-    return client.delete(resource_name)
-
-
 # --------------------------------------------------------------------------------------------
 # Security Automatic Provisioning Settings
 # --------------------------------------------------------------------------------------------
