@@ -967,7 +967,8 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
                         regular_priority_count=None, regular_priority_percentage=None, disk_controller_type=None,
                         enable_osimage_notification=None, max_surge=None, enable_hibernation=None,
                         enable_auto_os_upgrade=None, enable_proxy_agent=None, proxy_agent_mode=None,
-                        security_posture_reference_id=None, security_posture_reference_exclude_extensions=None):
+                        security_posture_reference_id=None, security_posture_reference_exclude_extensions=None,
+                        enable_resilient_vm_creation=None, enable_resilient_vm_deletion=None):
 
     # Build IP configuration
     ip_configuration = {}
@@ -1431,6 +1432,14 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
     if scale_in_policy:
         vmss_properties['scaleInPolicy'] = {'rules': scale_in_policy}
 
+    if enable_resilient_vm_creation is not None or enable_resilient_vm_deletion is not None:
+        resiliency_policy = {}
+        if enable_resilient_vm_creation is not None:
+            resiliency_policy['resilientVMCreationPolicy'] = {'enabled': enable_resilient_vm_creation}
+        if enable_resilient_vm_deletion is not None:
+            resiliency_policy['resilientVMDeletionPolicy'] = {'enabled': enable_resilient_vm_deletion}
+        vmss_properties['resiliencyPolicy'] = resiliency_policy
+
     security_profile = {}
     if encryption_at_host:
         security_profile['encryptionAtHost'] = encryption_at_host
